Crate lipbalm

Crate lipbalm 

Modules

colors
styles

Structs

Lipbalm
Style builde for terminal output. Call the methods to apply the desired styles and then call render to apply the styles to the text. Example: